// ------------------------------------------------------------------------------------
// <copyright file="EditorialesBL.cs" company="Universidad Distrital">
// Copyright (c) Universidad Distrital. All rights reserved.
// </copyright>
// <author>Camilo Prieto</author>
// ------------------------------------------------------------------------------------
namespace Biblioteca.Negocio.Clases.BL
{
	using System;
	using System.Collections.Generic;
	using System.Threading.Tasks;
	using Biblioteca.Datos.Clases.DAL.Repositorio;
	using Biblioteca.IC.Acciones.Repositorio;
	using Biblioteca.IC.DTO.Repositorio;
	using Biblioteca.IC.Recursos;
	using TransaccionalNet.EF.Clases;
	using UtilitariosNet.Clases.Comunes.Entidades;
	using Utilitarios.TransversalesNet.Clases.Comunes.Enumeraciones;

	/// <summary>
	/// Clase con las acciones de negocio de la entidad Editoriales
	/// </summary>
	public class EditorialesBL : AccesoComunBL, IEditorialesNegocioAccion
	{

		#region ATRIBUTOS
		/// <summary>
		/// Objeto para repositorio Editoriales
		/// <summary>
		/// Objeto para acciones Editoriales
		/// </summary>
		private Lazy<IEditorialesRepositorioAccion> editorialesRepositorioAccion;

		/// <summary>
		/// Objeto para entidad respuesta
		/// </summary>
		Respuesta<IEditorialesDTO> respuesta;

		#endregion ATRIBUTOS
		#region CONSTRUCTORES
		/// <summary>
		/// Inicializa una nueva instancia de la clase EditorialesBL
		/// </summary>
		/// <param name="argEditorialesRepositorioAccion">Acciones entidad Editoriales</param>
		public EditorialesBL(Lazy<IEditorialesRepositorioAccion> argEditorialesRepositorioAccion = null)
		{
			this.respuesta = new Respuesta<IEditorialesDTO>();
			this.editorialesRepositorioAccion = argEditorialesRepositorioAccion ?? new Lazy<IEditorialesRepositorioAccion>(() => new EditorialesDAL());
		}

		#endregion CONSTRUCTORES
		#region METODOS PUBLICOS
		/// <summary>
		/// Metodo consultar lista editoriales
		/// </summary>
		/// <returns>Respuesta tipo Editoriales </returns>
		public async Task<Respuesta<IEditorialesDTO>> ConsultarListaEditorialesAsync()
		{

			return await this.EjecutarTransaccionBDAsync<Respuesta<IEditorialesDTO>, EditorialesBL>(
			System.Transactions.IsolationLevel.ReadUncommitted,
			async () =>
			{
				 respuesta= await this.editorialesRepositorioAccion.Value.ConsultarListaEditorialesAsync();
				 respuesta.Resultado = true;
				 respuesta.TipoNotificacion = TipoNotificacion.Exitoso;
				 return respuesta;

			});

		}
		/// <summary>
		/// Metodo consultar por llave editoriales
		/// </summary>
		/// <param name="editoriales">Entidad a consultar</param>
		/// <returns>Respuesta tipo Editoriales </returns>
		public async Task<Respuesta<IEditorialesDTO>> ConsultarEditorialesLlaveAsync(IEditorialesDTO editoriales)
		{
			return await this.EjecutarTransaccionBDAsync<Respuesta<IEditorialesDTO>, EditorialesBL>(
			System.Transactions.IsolationLevel.ReadUncommitted,
			async () =>
			{
				 respuesta= await this.editorialesRepositorioAccion.Value.ConsultarEditorialesLlaveAsync(editoriales);
				 respuesta.Resultado = true;
				 respuesta.TipoNotificacion = TipoNotificacion.Exitoso;
				 return respuesta;

			});
		}

		/// <summary>
		/// Metodo editar editoriales
		/// </summary>
		/// <param name="editoriales">Entidad a editar</param>
		/// <returns>Respuesta tipo Editoriales </returns>
		public async Task<Respuesta<IEditorialesDTO>> EditarEditorialesAsync(IEditorialesDTO editoriales)
		{
			return await this.EjecutarTransaccionBDAsync<Respuesta<IEditorialesDTO>, EditorialesBL>(
			System.Transactions.IsolationLevel.ReadUncommitted,
			async () =>
			{
				 respuesta= await this.editorialesRepositorioAccion.Value.EditarEditorialesAsync(editoriales);
				 respuesta.Resultado = true;
				 respuesta.TipoNotificacion = TipoNotificacion.Exitoso;
				 respuesta.Mensajes.Add(rcsMensajesComunes.MensajeCreacionEdicionExitosa);
				 return respuesta;

			});
		}


		/// <summary>
		/// Metodo eliminar editoriales
		/// </summary>
		/// <param name="editoriales">Entidad a eliminar</param>
		/// <returns>Respuesta tipo Editoriales </returns>
		public async Task<Respuesta<IEditorialesDTO>> EliminarEditorialesAsync(IEditorialesDTO editoriales)
		{
			return await this.EjecutarTransaccionBDAsync<Respuesta<IEditorialesDTO>, EditorialesBL>(
			System.Transactions.IsolationLevel.ReadUncommitted,
			async () =>
			{
				 respuesta= await this.editorialesRepositorioAccion.Value.EliminarEditorialesAsync(editoriales);
				 respuesta.Resultado = true;
				 respuesta.TipoNotificacion = TipoNotificacion.Exitoso;
				 respuesta.Mensajes.Add(rcsMensajesComunes.MensajeEntidadEliminadaConExito);
				 return respuesta;

			});
		}

		/// <summary>
		/// Metodo guardar editoriales
		/// </summary>
		/// <param name="editoriales">Entidad a guardar</param>
		/// <returns>Respuesta tipo Editoriales </returns>
		public async Task<Respuesta<IEditorialesDTO>> GuardarEditorialesAsync(IEditorialesDTO editoriales)
		{
			return await this.EjecutarTransaccionBDAsync<Respuesta<IEditorialesDTO>, EditorialesBL>(
			System.Transactions.IsolationLevel.ReadUncommitted,
			async () =>
			{
				 respuesta= await this.editorialesRepositorioAccion.Value.GuardarEditorialesAsync(editoriales);
				 respuesta.Resultado = true;
				 respuesta.TipoNotificacion = TipoNotificacion.Exitoso;
				 respuesta.Mensajes.Add(rcsMensajesComunes.MensajeCreacionEdicionExitosa);
				 return respuesta;

			});
		}

		/// <summary>
		/// Metodo Guardar lista editoriales
		/// </summary>
		/// <param name="listaEditoriales">Lista de entidades a guardar</param>
		/// <returns>Respuesta tipo Editoriales </returns>
		public async Task<Respuesta<IEditorialesDTO>> GuardarListaEditorialesAsync(List<IEditorialesDTO> listaEditoriales)
		{
			return await this.EjecutarTransaccionBDAsync<Respuesta<IEditorialesDTO>, EditorialesBL>(
			System.Transactions.IsolationLevel.ReadUncommitted,
			async () =>
			{
				 respuesta= await this.editorialesRepositorioAccion.Value.GuardarListaEditorialesAsync(listaEditoriales);
				 respuesta.Resultado = true;
				 respuesta.TipoNotificacion = TipoNotificacion.Exitoso;
				 respuesta.Mensajes.Add(rcsMensajesComunes.MensajeCreacionEdicionExitosa);
				 return respuesta;

			});
		}
		#endregion METODOS PUBLICOS
		#region METODOS PRIVADOS
		#endregion METODOS PRIVADOS
	}
}

