// ------------------------------------------------------------------------------------
// <copyright file="EditorialesController.cs" company="Universidad Distrital">
// Copyright (c) Universidad Distrital. All rights reserved.
// </copyright>
// <author>Camilo Prieto</author>
// ------------------------------------------------------------------------------------
namespace Biblioteca.API.Controllers
{
	using System;
	using System.Collections.Generic;
	using System.Threading.Tasks;
	using Utilitarios.APINet.Clases.Ejecucion;
	using UtilitariosNet.Clases.Comunes.Entidades;
	using UtilitariosNet.Clases.Mapeador.Extensiones;
	using Biblioteca.API.Models.Repositorio;
	using Biblioteca.IC.Acciones.Repositorio;
	using Biblioteca.Negocio.Clases.BL;
	using Microsoft.AspNetCore.Mvc;
	
	/// <summary>
	/// Clase con las capaciades Rest de la entidad Editoriales
	/// </summary>
	[Route("api/Editoriales")]
	public class EditorialesController : AccesoComunAPI
	{


		/// <summary>
		/// Objeto para negocio Editoriales
		/// </summary>
		private Lazy<IEditorialesNegocioAccion> negocioEditoriales;

		
		/// <summary>
		/// Inicializa una nueva instancia de la clase EditorialesController
		/// </summary>
		public EditorialesController()
		{
			this.negocioEditoriales = new Lazy<IEditorialesNegocioAccion>(
										() => new EditorialesBL());
		}
		
		/// <summary>
		/// Metodo consultar lista editoriales
		/// </summary>
		/// <returns>Respuesta tipo Editoriales </returns>
		[HttpGet]
		[Route("ConsultarListaEditoriales")]
		public async Task<Respuesta<Editoriales>> ConsultarListaEditoriales()
		{
			return await this.EjecutarTransaccionAPI<Task<Respuesta<Editoriales>>, EditorialesController>(async () =>
			{
				return Mapeador.MapearObjetoPorJson<Respuesta<Editoriales>>(await negocioEditoriales.Value.ConsultarListaEditorialesAsync());
			});
		}
		
		/// <summary>
		/// Metodo consultar por llave editoriales
		/// </summary>
		/// <param name="editoriales">Entidad a consultar</param>
		/// <returns>Respuesta tipo Editoriales </returns>
		[HttpPost]
		[Route("ConsultarEditorialesLlave")]
		public async Task<Respuesta<Editoriales>> ConsultarEditorialesLlave(Editoriales editoriales)
		{
			return await this.EjecutarTransaccionAPI<Task<Respuesta<Editoriales>>, EditorialesController>(async () =>
			{
				return Mapeador.MapearObjetoPorJson<Respuesta<Editoriales>>(await negocioEditoriales.Value.ConsultarEditorialesLlaveAsync(editoriales));
			});
		}
		
		/// <summary>
		/// Metodo guardar editoriales
		/// </summary>
		/// <param name="editoriales">Entidad a guardar</param>
		/// <returns>Respuesta tipo Editoriales </returns>
		[HttpPost]
		[Route("GuardarEditoriales")]
		public async Task<Respuesta<Editoriales>> GuardarEditoriales(Editoriales editoriales)
		{
			return await this.EjecutarTransaccionAPI<Task<Respuesta<Editoriales>>, EditorialesController>(async () =>
			{
				return Mapeador.MapearObjetoPorJson<Respuesta<Editoriales>>(await negocioEditoriales.Value.GuardarEditorialesAsync(editoriales));
			});
		}
		
		/// <summary>
		/// Metodo editar editoriales
		/// </summary>
		/// <param name="editoriales">Entidad a editar</param>
		/// <returns>Respuesta tipo Editoriales </returns>
		[HttpPut]
		[Route("EditarEditoriales")]
		public async Task<Respuesta<Editoriales>> EditarEditoriales(Editoriales editoriales)
		{
			return await this.EjecutarTransaccionAPI<Task<Respuesta<Editoriales>>, EditorialesController>(async () =>
			{
				return Mapeador.MapearObjetoPorJson<Respuesta<Editoriales>>(await negocioEditoriales.Value.EditarEditorialesAsync(editoriales));
			});
		}
		
		/// <summary>
		/// Metodo eliminar editoriales
		/// </summary>
		/// <param name="editoriales">Entidad a eliminar</param>
		/// <returns>Respuesta tipo Editoriales </returns>
		[HttpDelete]
		[Route("EliminarEditoriales")]
		public async Task<Respuesta<Editoriales>> EliminarEditoriales(Editoriales editoriales)
		{
			return await this.EjecutarTransaccionAPI<Task<Respuesta<Editoriales>>, EditorialesController>(async () =>
			{
				return Mapeador.MapearObjetoPorJson<Respuesta<Editoriales>>(await negocioEditoriales.Value.EliminarEditorialesAsync(editoriales));
			});
		}
	}
}

